@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,18 +14,18 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides support for synthesizing keyboard and mouse events."""
 
-__id__        = "$Id: eventsynthesizer.py 1533 2006-10-06 07:59:04Z richb $"
-__version__   = "$Revision: 1533 $"
-__date__      = "$Date: 2006-10-06 03:59:04 -0400 (Fri, 06 Oct 2006) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import atspi
+import pyatspi
 import debug
 
 def generateMouseEvent(x, y, eventName):
@@ -47,8 +47,7 @@ def generateMouseEvent(x, y, eventName):
                   "SYNTHESIZING MOUSE EVENT: (%d, %d) %s"\
                   % (x, y, eventName))
 
-    d = atspi.Registry().registry.getDeviceEventController()
-    d.generateMouseEvent(x, y, eventName)
+    pyatspi.Registry.generateMouseEvent(x, y, eventName)
 
 def clickObject(obj, button):
     """Performs a button click on the given Accessible.
@@ -57,8 +56,7 @@ def clickObject(obj, button):
     - obj: the Accessible
     - button: an integer representing the mouse button number
     """
-
-    extents = obj.extents
+    extents = obj.queryComponent().getExtents(pyatspi.DESKTOP_COORDS)
     x = extents.x + extents.width/2
     y = extents.y + extents.height/2
     generateMouseEvent(x, y, "b%dc" % button)
@@ -74,7 +72,7 @@ def clickPoint(x, y, button):
 
     generateMouseEvent(x, y, "b%dc" % button)
 
-def generateKeyboardEvent(keycode, keystring, type):
+def generateKeyboardEvent(keycode, keystring, eventType):
     """Generates a keyboard event.
 
     Arguments:
@@ -85,11 +83,10 @@ def generateKeyboardEvent(keycode, keystring, type):
               being synthesized; this type of keyboard event synthesis does
               not emulate hardware keypresses but injects the string
               as though a composing input method (such as XIM) were used.
-    - type:   an AccessibleKeySynthType flag indicating whether keyval
+    - eventType: an AccessibleKeySynthType flag indicating whether keyval
               is to be interpreted as a keysym rather than a keycode
-              (atspi.Accessibility.KEY_SYM), or whether to synthesize
+              (pyatspi.KEY_SYM), or whether to synthesize
               KEY_PRESS, KEY_RELEASE, or both (KEY_PRESSRELEASE).
     """
 
-    d = atspi.Registry().registry.getDeviceEventController()
-    d.generateKeyboardEvent(keycode, keystring, type)
+    pyatspi.Registry.generateKeyboardEvent(keycode, keystring, eventType)
